:
# NAME:
#	interlock - provide interlocking between a number of processes
#
# SYNOPSIS:
#	INTERLOCKS="name ..."
#	. interlock.sh
#	
# DESCRIPTION:
#	This script uses only1.sh(1) to provide interlocking between
#	the processes names in "INTERLOCKS".
#
#	This is a tad complex, but necessary to avoid race conditions.
#	This file is typically sourced by rc.sh while processing a
#	directory such as monthly.d, in which case "realName" would be
#	monthly.
#
#	'interlock.sh' first waits for the lock 'interlock' and then
#	does a do or die grab for the "realName" lock.
#
#	If we get this far, we want to then waitfor each of the locks
#	named in "INTERLOCKS", but we want those to become invalid
#	once we have finished waiting, so we collect the names of the
#	lock files and remove them before we finish.
#
# SEE ALSO:
#	only1.sh(1)
#	
# AUTHOR:
#	Simon J. Gerraty <sjg@crufty.net>
#

#	
# RCSid:
#	$Id: interlock.sh,v 1.8 2003/06/29 01:22:28 sjg Exp $
#
#	@(#) Copyright (c) 1995 Simon J. Gerraty
#
#	This file is provided in the hope that it will
#	be of use.  There is absolutely NO WARRANTY.
#	Permission to copy, redistribute or otherwise
#	use this file is hereby granted provided that 
#	the above copyright notice and this notice are
#	left intact. 
#      
#	Please send copies of changes and bug-fixes to:
#	sjg@crufty.net
#

Mydir=${Mydir:-`dirname $0`}
PATH=/usr/local/share/bin:$PATH

# first ensure we don't end up with 30 instances of hourly
# waiting on the interlock
set -- only1 "$@"
. only1.sh
# there is only one instance running now..., lose the fake arg1
shift

# need to remeber this
realName=$Myname
interlockMutex=$PidF

Logger() {
	lev=$1; shift
	echo "$*" | logger -t "$realName[$$]" -p ${opt_L:-local1}.$lev 
}

waitfor() {
	pid=$1

	loop=0
	report=${INTERLOCK_REPORT:-60}

	while :
	do
		e=`LANG=C LC_ALL=C kill -0 $pid 2>&1`
		case "$e" in
		"") ;;
		*such*)	break;;
		*denied*)
			Logger err "kill -0 $pid: $e"
			;;
		*)
			Logger debug "kill -0 $pid: $e"
			;;
		esac
		if [ $loop -gt $report ]; then
			Logger info "waiting for $Myname[$pid]"
			loop=0
			if [ $report -lt 720 ]; then
				report=`expr $report + 60`
			fi
		fi
		loop=`expr $loop + 1`
		${TWDL:-:}
		sleep 10
	done
}

pidfiles=
for Myname in interlock $realName $INTERLOCKS
do
	case "$realName" in
	*$Myname*)
		# this is the lock that matters
		Only1Runner=0
		. only1.sh
                InterlockMutex=$PidF
                export InterlockMutex
		continue
		;;
	esac
	Only1Runner=waitfor
	. only1.sh
	# if we get to here, we have the lock
	pidfiles="$pidfiles $PidF"
done
rm -f $pidfiles $interlockMutex
Myname=$realName
