#!/usr/bin/env perl
#
# NAME:
#	ip2h - convert IP addresses to/from hex
#
# SYNOPSIS:
#	ip2h ["file" ...]
#
# DESCRIPTION:
#	This script reads addresses from "file" or stdin.
#	It accepts addresses in dotted decimal, octal and hex and
#	displays its output in all three.
#
#	For example:
#.nf
#
#	echo 127.0.0.1 | ip2h.pl
#	0x7f000001 -> 017700000001 -> 127.0.0.1
#.fi
#
# AUTHOR:
#	Simon J. Gerraty <sjg@crufty.net>
#	

# RCSid:
#	$Id: ip2h.pl,v 1.5 2001/08/30 07:48:37 sjg Exp $
#
#	@(#) Copyright (c) 1993 Simon J. Gerraty
#
#	This file is provided in the hope that it will
#	be of use.  There is absolutely NO WARRANTY.
#	Permission to copy, redistribute or otherwise
#	use this file is hereby granted provided that 
#	the above copyright notice and this notice are
#	left intact. 
#      
#	Please send copies of changes and bug-fixes to:
#	sjg@crufty.net
#

if ($0 =~ m,^(.*)/([^/]+)$,) {
  $Mydir = $1;
  $Myname = $2;
} else {
  $Mydir = '.';
  $Myname = $0;
}

push(@INC, $Mydir);

require 'ip_subs.pl';

while (<>) {
  chop;
  if (m/\./) {
    $n = &ip2hex($_);
    printf "%#x -> %#o -> %s\n", $n, $n, $_;
  } elsif (m/^0/ && $_ !~ m/^0x/) {
    $n = oct($_);
    printf "%#x -> %#o -> %s\n", $n, $n, &hex2ip($n);
  } else {
    $n = hex($_);
    printf "%#x -> %#o -> %s\n", $n, $n, &hex2ip($n);
  }
}
